@@ -6,8 +6,7 @@ from dbus_next.constants import MessageType
 from dbus_next.message import Message
 from dbus_next.signature import Variant
 
-from bleak import BleakError
-from bleak.exc import BleakDBusError
+from ...exc import BleakError, BleakDBusError
 
 _address_regex = re.compile("^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$")
 
@@ -17,7 +16,7 @@ def assert_reply(reply: Message):
 
     Raises:
         BleakDBusError: if the message type is ``MessageType.ERROR``
-        AssentationError: if the message type is not ``MessageType.METHOD_RETURN``
+        AssertionError: if the message type is not ``MessageType.METHOD_RETURN``
     """
     if reply.message_type == MessageType.ERROR:
         raise BleakDBusError(reply.error_name, reply.body)
