@@ -8,12 +8,6 @@ class BleakError(Exception):
     pass
 
 
-class BleakDotNetTaskError(BleakError):
-    """Wrapped exception that occurred in .NET async Task."""
-
-    pass
-
-
 class BleakDBusError(BleakError):
     """Specialized exception type for D-Bus errors."""
 
@@ -122,3 +116,31 @@ CONTROLLER_ERROR_CODES = {
     0x44: "Operation Cancelled by Host",
     0x45: "Packet Too Long",
 }
+
+# as defined in Bluetooth Core Specification v5.2, volume 3, part F, section 3.4.1.1, table 3.4.
+PROTOCOL_ERROR_CODES = {
+    0x01: "Invalid Handle",
+    0x02: "Read Not Permitted",
+    0x03: "Write Not Permitted",
+    0x04: "Invalid PDU",
+    0x05: "Insufficient Authentication",
+    0x06: "Request Not Supported",
+    0x07: "Invalid Offset",
+    0x08: "Insufficient Authorization",
+    0x09: "Prepare Queue Full",
+    0x0A: "Attribute Not Found",
+    0x0B: "Attribute Not Long",
+    0x0C: "Insufficient Encryption Key Size",
+    0x0D: "Invalid Attribute Value Length",
+    0x0E: "Unlikely Error",
+    0x0F: "Insufficient Authentication",
+    0x10: "Unsupported Group Type",
+    0x11: "Insufficient Resource",
+    0x12: "Database Out Of Sync",
+    0x13: "Value Not Allowed",
+    # REVISIT: do we need Application Errors 0x80-0x9F?
+    0xFC: "Write Request Rejected",
+    0xFD: "Client Characteristic Configuration Descriptor Improperly Configured",
+    0xFE: "Procedure Already in Progress",
+    0xFF: "Out of Range",
+}
